@@ -12,7 +12,7 @@ package lexicals;
 use 5.005008;
 use strict;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use PadWalker;
 
@@ -21,12 +21,14 @@ our @EXPORT = qw(lexicals);
 
 sub lexicals {
     my $hash = PadWalker::peek_my(1);
-    my $lex = {};
-    while ( my ($k, $v) = each %$hash ) {
-        $k =~ s/^\$//;
-        $lex->{$k} = $$v;
-    }
-    return $lex;
+    return +{
+        map {
+            my $v = $hash->{$_};
+            $v = $$v if ref($v) =~ m'^(SCALAR|REF)$';
+            s/^[\$\@\%\*]//;
+            ($_, $v);
+        } reverse sort keys %$hash
+    };
 }
 
 1;
@@ -64,6 +66,36 @@ Assuming you have a $foo and $bar defined, you get the same thing.
 The `lexicals` module exports a function called `lexicals`. This function
 returns the lexicals as a hash reference (in scalar or list context).
 
+=head1 ARRAYS AND HASHES
+
+The above examples deal with lexical scalars. You can also get back lexical
+arrays and hashes. Note: since there is no sigil to tell scalars from arrays
+from hashes, you can't get back a scalar and an array or hash of the same
+name. In this case, SCALAR beats HASH beats ARRAY. Why? Because I said so!
+(Actually I just used the sort order of the sigils).
+
+    sub foo {
+        my %h = ( O => 'HAI' );
+        my @a = [ qw( foo bar baz ) ];
+        my $s = 42;
+        my %x = ( O => 'HAI' );
+        my @x = [ qw( foo bar baz ) ];
+        my $x = 42;
+        print Dump lexicals;
+    }
+
+would yield:
+
+    ---
+    a:
+    - foo
+    - bar
+    - baz
+    h:
+      O: HAI
+    s: 42
+    x: 42
+
 =head1 NOTE
 
 The C<lexicals> function only reports the lexical variables variables that
